Index: chrome/browser/chrome_browser_main_win.cc |
diff --git a/chrome/browser/chrome_browser_main_win.cc b/chrome/browser/chrome_browser_main_win.cc |
index 99a0922b770a7860954421bb084b70c92d98bde2..bf521435e96daaaa45003ec3b9b51d319002ce03 100644 |
--- a/chrome/browser/chrome_browser_main_win.cc |
+++ b/chrome/browser/chrome_browser_main_win.cc |
@@ -312,10 +312,11 @@ void ChromeBrowserMainPartsWin::PreMainMessageLoopStart() { |
} |
int ChromeBrowserMainPartsWin::PreCreateThreads() { |
-// Record whether the machine is domain joined in a crash key. This will be used |
-// to better identify whether crashes are from enterprise users. |
- base::debug::SetCrashKeyValue(crash_keys::kEnrolledToDomain, |
- base::win::IsEnrolledToDomain() ? "yes" : "no"); |
+ // Record whether the machine is enterprise managed in a crash key. This will |
+ // be used to better identify whether crashes are from enterprise users. |
+ base::debug::SetCrashKeyValue( |
+ crash_keys::kIsEnterpriseManaged, |
+ base::win::IsEnterpriseManaged() ? "yes" : "no"); |
int rv = ChromeBrowserMainParts::PreCreateThreads(); |